@@ -50,3 +50,12 @@ test_that("the errors message includes the name of the user's data", {
 
   expect_error(prep_trajectory(bad_region), "bad_region")
 })
+
+test_that("columns in output match what is documented in `data_dictionary`", {
+  out <- prep_trajectory(test_data)
+
+  data_dict <- dplyr::filter(data_dictionary, dataset == "prep_trajectory_output")
+
+  expect_setequal(names(out), data_dict[["column"]])
+  expect_mapequal(sapply(out, typeof), setNames(data_dict[["typeof"]], data_dict[["column"]]))
+})
